@@ -8,6 +8,7 @@ import (
 	. "github.com/onsi/gomega"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
+	instanceutils "github.com/weaveworks/eksctl/pkg/utils/instance"
 )
 
 var _ = Describe("GPU instance support", func() {
@@ -15,6 +16,7 @@ var _ = Describe("GPU instance support", func() {
 	type gpuInstanceEntry struct {
 		gpuInstanceType string
 		amiFamily       string
+		customErr       string
 
 		expectUnsupportedErr bool
 	}
@@ -22,7 +24,13 @@ var _ = Describe("GPU instance support", func() {
 	assertValidationError := func(e gpuInstanceEntry, err error) {
 		if e.expectUnsupportedErr {
 			Expect(err).To(HaveOccurred())
-			Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("GPU instance types are not supported for %s", e.amiFamily))))
+			if e.customErr != "" {
+				Expect(err).To(MatchError(e.customErr))
+			} else if instanceutils.IsNvidiaInstanceType(e.gpuInstanceType) {
+				Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("GPU instance types are not supported for %s", e.amiFamily))))
+			} else {
+				Expect(err).To(MatchError(ContainSubstring(fmt.Sprintf("Inferentia instance types are not supported for %s", e.amiFamily))))
+			}
 			return
 		}
 		Expect(err).NotTo(HaveOccurred())
@@ -33,7 +41,7 @@ var _ = Describe("GPU instance support", func() {
 		mng.InstanceType = e.gpuInstanceType
 		mng.AMIFamily = e.amiFamily
 		mng.InstanceSelector = &api.InstanceSelector{}
-		assertValidationError(e, api.ValidateManagedNodeGroup(mng, 0))
+		assertValidationError(e, api.ValidateManagedNodeGroup(0, mng))
 	},
 		Entry("AL2", gpuInstanceEntry{
 			gpuInstanceType: "asdf",
@@ -47,12 +55,18 @@ var _ = Describe("GPU instance support", func() {
 			amiFamily:            api.NodeImageFamilyBottlerocket,
 			gpuInstanceType:      "g4dn.xlarge",
 			expectUnsupportedErr: true,
+			customErr:            fmt.Sprintf("NVIDIA GPU instance types are not supported for managed nodegroups with AMIFamily %s", api.NodeImageFamilyBottlerocket),
 		}),
 		Entry("Ubuntu2004", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyUbuntu2004,
 			gpuInstanceType:      "g4dn.xlarge",
 			expectUnsupportedErr: true,
 		}),
+		Entry("Bottlerocket", gpuInstanceEntry{
+			amiFamily:            api.NodeImageFamilyBottlerocket,
+			gpuInstanceType:      "inf1.xlarge",
+			expectUnsupportedErr: true,
+		}),
 	)
 
 	DescribeTable("unmanaged nodegroups", func(e gpuInstanceEntry) {
@@ -70,12 +84,20 @@ var _ = Describe("GPU instance support", func() {
 			gpuInstanceType: "g5.12xlarge",
 			amiFamily:       api.NodeImageFamilyAmazonLinux2,
 		}),
+		Entry("AL2", gpuInstanceEntry{
+			gpuInstanceType: "inf1.xlarge",
+			amiFamily:       api.NodeImageFamilyAmazonLinux2,
+		}),
 		Entry("AMI unset", gpuInstanceEntry{
 			gpuInstanceType: "g4dn.xlarge",
 		}),
+		Entry("Bottlerocket", gpuInstanceEntry{
+			amiFamily:       api.NodeImageFamilyBottlerocket,
+			gpuInstanceType: "g4dn.xlarge",
+		}),
 		Entry("Bottlerocket", gpuInstanceEntry{
 			amiFamily:            api.NodeImageFamilyBottlerocket,
-			gpuInstanceType:      "g4dn.xlarge",
+			gpuInstanceType:      "inf1.xlarge",
 			expectUnsupportedErr: true,
 		}),
 		Entry("Ubuntu2004", gpuInstanceEntry{
